@@ -60,12 +60,15 @@ setMethod("getGroupsFormula", signature(object = "ANY"),
 
 
 setMethod("getGroups", signature(object="data.frame", form="formula"),
-          function(object, form, level, data, sep)
+          function(object, form, level, data, sep, ...)
               eval(getGroupsFormula(form)[[2]], object))
 
-setMethod("getGroups", signature(object="groupedData"),
-          function(object, form, level, data, sep) {
-              object = object@data
-              callGeneric()
+setMethod("getGroups", signature(object="groupedData", form="missing"),
+          function(object, form, level, data, sep, ...) {
+              nCall <- match.call()
+              nCall$object <- substitute(object@data, list(object = nCall$object))
+              if(is.null(nCall$form)) nCall$form <- formula(object)
+              eval(nCall, parent.frame())
           })
 
+              
